@@ -2,8 +2,6 @@ import base64
 import unittest
 from unittest import mock
 
-import django
-import pytest
 from django.conf import settings
 from django.contrib.auth.models import AnonymousUser, Group, Permission, User
 from django.db import models
@@ -14,7 +12,6 @@ from rest_framework import (
     HTTP_HEADER_ENCODING, authentication, generics, permissions, serializers,
     status, views
 )
-from rest_framework.compat import PY36
 from rest_framework.routers import DefaultRouter
 from rest_framework.test import APIRequestFactory
 from tests.models import BasicModel
@@ -250,12 +247,6 @@ class BasicPermModel(models.Model):
     class Meta:
         app_label = 'tests'
 
-        if django.VERSION < (2, 1):
-            permissions = (
-                ('view_basicpermmodel', 'Can view basic perm model'),
-                # add, change, delete built in to django
-            )
-
 
 class BasicPermSerializer(serializers.ModelSerializer):
     class Meta:
@@ -438,6 +429,7 @@ class BasicPerm(permissions.BasePermission):
 
 class BasicPermWithDetail(permissions.BasePermission):
     message = 'Custom: You cannot access this resource'
+    code = 'permission_denied_custom'
 
     def has_permission(self, request, view):
         return False
@@ -450,6 +442,7 @@ class BasicObjectPerm(permissions.BasePermission):
 
 class BasicObjectPermWithDetail(permissions.BasePermission):
     message = 'Custom: You cannot access this resource'
+    code = 'permission_denied_custom'
 
     def has_object_permission(self, request, view, obj):
         return False
@@ -492,30 +485,35 @@ class CustomPermissionsTests(TestCase):
         credentials = basic_auth_header('username', 'password')
         self.request = factory.get('/1', format='json', HTTP_AUTHORIZATION=credentials)
         self.custom_message = 'Custom: You cannot access this resource'
+        self.custom_code = 'permission_denied_custom'
 
     def test_permission_denied(self):
         response = denied_view(self.request, pk=1)
         detail = response.data.get('detail')
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
         self.assertNotEqual(detail, self.custom_message)
+        self.assertNotEqual(detail.code, self.custom_code)
 
     def test_permission_denied_with_custom_detail(self):
         response = denied_view_with_detail(self.request, pk=1)
         detail = response.data.get('detail')
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
         self.assertEqual(detail, self.custom_message)
+        self.assertEqual(detail.code, self.custom_code)
 
     def test_permission_denied_for_object(self):
         response = denied_object_view(self.request, pk=1)
         detail = response.data.get('detail')
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
         self.assertNotEqual(detail, self.custom_message)
+        self.assertNotEqual(detail.code, self.custom_code)
 
     def test_permission_denied_for_object_with_custom_detail(self):
         response = denied_object_view_with_detail(self.request, pk=1)
         detail = response.data.get('detail')
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
         self.assertEqual(detail, self.custom_message)
+        self.assertEqual(detail.code, self.custom_code)
 
 
 class PermissionsCompositionTests(TestCase):
@@ -600,7 +598,6 @@ class PermissionsCompositionTests(TestCase):
         )
         assert composed_perm().has_permission(request, None) is True
 
-    @pytest.mark.skipif(not PY36, reason="assert_called_once() not available")
     def test_or_lazyness(self):
         request = factory.get('/1', format='json')
         request.user = AnonymousUser()
@@ -609,19 +606,18 @@ class PermissionsCompositionTests(TestCase):
             with mock.patch.object(permissions.IsAuthenticated, 'has_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.AllowAny | permissions.IsAuthenticated)
                 hasperm = composed_perm().has_permission(request, None)
-                self.assertIs(hasperm, True)
-                mock_allow.assert_called_once()
+                assert hasperm is True
+                assert mock_allow.call_count == 1
                 mock_deny.assert_not_called()
 
         with mock.patch.object(permissions.AllowAny, 'has_permission', return_value=True) as mock_allow:
             with mock.patch.object(permissions.IsAuthenticated, 'has_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.IsAuthenticated | permissions.AllowAny)
                 hasperm = composed_perm().has_permission(request, None)
-                self.assertIs(hasperm, True)
-                mock_deny.assert_called_once()
-                mock_allow.assert_called_once()
+                assert hasperm is True
+                assert mock_deny.call_count == 1
+                assert mock_allow.call_count == 1
 
-    @pytest.mark.skipif(not PY36, reason="assert_called_once() not available")
     def test_object_or_lazyness(self):
         request = factory.get('/1', format='json')
         request.user = AnonymousUser()
@@ -630,19 +626,18 @@ class PermissionsCompositionTests(TestCase):
             with mock.patch.object(permissions.IsAuthenticated, 'has_object_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.AllowAny | permissions.IsAuthenticated)
                 hasperm = composed_perm().has_object_permission(request, None, None)
-                self.assertIs(hasperm, True)
-                mock_allow.assert_called_once()
+                assert hasperm is True
+                assert mock_allow.call_count == 1
                 mock_deny.assert_not_called()
 
         with mock.patch.object(permissions.AllowAny, 'has_object_permission', return_value=True) as mock_allow:
             with mock.patch.object(permissions.IsAuthenticated, 'has_object_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.IsAuthenticated | permissions.AllowAny)
                 hasperm = composed_perm().has_object_permission(request, None, None)
-                self.assertIs(hasperm, True)
-                mock_deny.assert_called_once()
-                mock_allow.assert_called_once()
+                assert hasperm is True
+                assert mock_deny.call_count == 1
+                assert mock_allow.call_count == 1
 
-    @pytest.mark.skipif(not PY36, reason="assert_called_once() not available")
     def test_and_lazyness(self):
         request = factory.get('/1', format='json')
         request.user = AnonymousUser()
@@ -651,19 +646,18 @@ class PermissionsCompositionTests(TestCase):
             with mock.patch.object(permissions.IsAuthenticated, 'has_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.AllowAny & permissions.IsAuthenticated)
                 hasperm = composed_perm().has_permission(request, None)
-                self.assertIs(hasperm, False)
-                mock_allow.assert_called_once()
-                mock_deny.assert_called_once()
+                assert hasperm is False
+                assert mock_allow.call_count == 1
+                assert mock_deny.call_count == 1
 
         with mock.patch.object(permissions.AllowAny, 'has_permission', return_value=True) as mock_allow:
             with mock.patch.object(permissions.IsAuthenticated, 'has_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.IsAuthenticated & permissions.AllowAny)
                 hasperm = composed_perm().has_permission(request, None)
-                self.assertIs(hasperm, False)
+                assert hasperm is False
+                assert mock_deny.call_count == 1
                 mock_allow.assert_not_called()
-                mock_deny.assert_called_once()
 
-    @pytest.mark.skipif(not PY36, reason="assert_called_once() not available")
     def test_object_and_lazyness(self):
         request = factory.get('/1', format='json')
         request.user = AnonymousUser()
@@ -672,14 +666,14 @@ class PermissionsCompositionTests(TestCase):
             with mock.patch.object(permissions.IsAuthenticated, 'has_object_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.AllowAny & permissions.IsAuthenticated)
                 hasperm = composed_perm().has_object_permission(request, None, None)
-                self.assertIs(hasperm, False)
-                mock_allow.assert_called_once()
-                mock_deny.assert_called_once()
+                assert hasperm is False
+                assert mock_allow.call_count == 1
+                assert mock_deny.call_count == 1
 
         with mock.patch.object(permissions.AllowAny, 'has_object_permission', return_value=True) as mock_allow:
             with mock.patch.object(permissions.IsAuthenticated, 'has_object_permission', return_value=False) as mock_deny:
                 composed_perm = (permissions.IsAuthenticated & permissions.AllowAny)
                 hasperm = composed_perm().has_object_permission(request, None, None)
-                self.assertIs(hasperm, False)
+                assert hasperm is False
+                assert mock_deny.call_count == 1
                 mock_allow.assert_not_called()
-                mock_deny.assert_called_once()
